
=====
Usage
=====

This section contains information, including examples, about how to use
*django-thumbnail-works* in your existing Django projects or applications.


The EnhancedImageField
======================

.. autoclass:: thumbnail_works.fields.EnhancedImageField


Accessing thumbnails
====================

.. autoclass:: thumbnail_works.fields.EnhancedImageFieldFile


Is that it?
===========

Indeed, that's pretty much all you can do with ``django-thumbnail-works``.
